From d2fc89135cb2360f7905505fef33430179cd97e0 Mon Sep 17 00:00:00 2001
From: Sven Willenbuecher <sven.willenbuecher@kuehne-nagel.com>
Date: Thu, 23 Dec 2021 07:13:27 +0100
Subject: [PATCH 1/4] add hints script for the platform aix

- introduce new macro varibale MKDIR because the aix mkdir does not know
the option -v
- get rid of the options -iname and -print0 of GNU find because the aix
find does not known these
---
 src/password-store.sh | 15 ++++++++-------
 src/platform/aix.sh   |  1 +
 2 files changed, 9 insertions(+), 7 deletions(-)
 create mode 100644 src/platform/aix.sh

diff --git a/src/password-store.sh b/src/password-store.sh
index aef8d72..6abd8ce 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -137,7 +137,7 @@ reencrypt_path() {
 			mv "$passfile_temp" "$passfile" || rm -f "$passfile_temp"
 		fi
 		prev_gpg_recipients="${GPG_RECIPIENTS[*]}"
-	done < <(find "$1" -path '*/.git' -prune -o -path '*/.extensions' -prune -o -iname '*.gpg' -print0)
+	done < <(find "$1" -path '*/.git' -prune -o -path '*/.extensions' -prune -o -name '*.[Gg][Pp][Gg]' -exec printf '%s\0' {} \;)
 }
 check_sneaky_paths() {
 	local path
@@ -245,6 +245,7 @@ tmpdir() {
 GETOPT="getopt"
 SHRED="shred -f -z"
 BASE64="base64"
+MKDIR="mkdir -p -v"
 
 source "$(dirname "$0")/platform/$(uname | cut -d _ -f 1 | tr '[:upper:]' '[:lower:]').sh" 2>/dev/null # PLATFORM_FUNCTION_FILE
 
@@ -344,7 +345,7 @@ cmd_init() {
 		fi
 		rmdir -p "${gpg_id%/*}" 2>/dev/null
 	else
-		mkdir -v -p "$PREFIX/$id_path"
+		$MKDIR "$PREFIX/$id_path"
 		printf "%s\n" "$@" > "$gpg_id"
 		local id_print="$(printf "%s, " "$@")"
 		echo "Password store initialized for ${id_print%, }${id_path:+ ($id_path)}"
@@ -430,7 +431,7 @@ cmd_grep() {
 		passfile="${passfile##*/}"
 		printf "\e[94m%s\e[1m%s\e[0m:\n" "$passfile_dir" "$passfile"
 		echo "$grepresults"
-	done < <(find -L "$PREFIX" -path '*/.git' -prune -o -path '*/.extensions' -prune -o -iname '*.gpg' -print0)
+	done < <(find -L "$PREFIX" -path '*/.git' -prune -o -path '*/.extensions' -prune -o -name '*.[Gg][Pp][Gg]' -exec printf '%s\0' {} \;)
 }
 
 cmd_insert() {
@@ -453,7 +454,7 @@ cmd_insert() {
 
 	[[ $force -eq 0 && -e $passfile ]] && yesno "An entry already exists for $path. Overwrite it?"
 
-	mkdir -p -v "$PREFIX/$(dirname -- "$path")"
+	$MKDIR "$PREFIX/$(dirname -- "$path")"
 	set_gpg_recipients "$(dirname -- "$path")"
 
 	if [[ $multiline -eq 1 ]]; then
@@ -487,7 +488,7 @@ cmd_edit() {
 
 	local path="${1%/}"
 	check_sneaky_paths "$path"
-	mkdir -p -v "$PREFIX/$(dirname -- "$path")"
+	$MKDIR "$PREFIX/$(dirname -- "$path")"
 	set_gpg_recipients "$(dirname -- "$path")"
 	local passfile="$PREFIX/$path.gpg"
 	set_git "$passfile"
@@ -529,7 +530,7 @@ cmd_generate() {
 	check_sneaky_paths "$path"
 	[[ $length =~ ^[0-9]+$ ]] || die "Error: pass-length \"$length\" must be a number."
 	[[ $length -gt 0 ]] || die "Error: pass-length must be greater than zero."
-	mkdir -p -v "$PREFIX/$(dirname -- "$path")"
+	$MKDIR "$PREFIX/$(dirname -- "$path")"
 	set_gpg_recipients "$(dirname -- "$path")"
 	local passfile="$PREFIX/$path.gpg"
 	set_git "$passfile"
@@ -618,7 +619,7 @@ cmd_copy_move() {
 	echo "$old_path"
 	[[ -e $old_path ]] || die "Error: $1 is not in the password store."
 
-	mkdir -p -v "${new_path%/*}"
+	$MKDIR "${new_path%/*}"
 	[[ -d $old_path || -d $new_path || $new_path == */ ]] || new_path="${new_path}.gpg"
 
 	local interactive="-i"
diff --git a/src/platform/aix.sh b/src/platform/aix.sh
new file mode 100644
index 0000000..03a3958
--- /dev/null
+++ b/src/platform/aix.sh
@@ -0,0 +1 @@
+MKDIR='mkdir -p'
-- 
2.20.1

